nginc
=====

A small wrapper around nginx to start it from the commandline as easy as *SimpleHTTPServer*.

To serve the current working directory on port 8080:

  $ nginc

For more options see *nginc -h*
